@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Invalid Federated Cloud ID" : "잘못된 연합 클라우드 ID",
     "Sharing %s failed, because this item is already shared with %s" : "%s을(를) 공유할 수 없습니다. 이미 %s 님과 공유되어 있습니다",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다."
+    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다.",
+    "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음"
 },
 "nplurals=1; plural=0;");
