@@ -117,6 +117,13 @@ OC.L10N.register(
     "No favorites" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
     "Text file" : "Ficheiro de Texto",
-    "New text file.txt" : "Novo texto ficheiro.txt"
+    "New text file.txt" : "Novo texto ficheiro.txt",
+    "Changed by %2$s" : "Alterado por %2$s",
+    "Deleted by %2$s" : "Eliminado por %2$s",
+    "Restored by %2$s" : "Restaurado por %2$s",
+    "You changed %1$s" : "Alterou %1$s",
+    "You created %1$s" : "Criou %1$s",
+    "You deleted %1$s" : "Apagou %1$s",
+    "You restored %1$s" : "Restaurou %1$s"
 },
 "nplurals=2; plural=(n != 1);");
