@@ -114,6 +114,13 @@ OC.L10N.register(
     "No favorites" : "Inga favoriter",
     "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer visas här",
     "Text file" : "Textfil",
-    "New text file.txt" : "nytextfil.txt"
+    "New text file.txt" : "nytextfil.txt",
+    "Changed by %2$s" : "Ändrad av %2$s",
+    "Deleted by %2$s" : "Bortagen av %2$s",
+    "Restored by %2$s" : "Återställd av %2$s",
+    "You changed %1$s" : "Du ändrade %1$s",
+    "You created %1$s" : "Du skapade %1$s",
+    "You deleted %1$s" : "Du raderade %1$s",
+    "You restored %1$s" : "Du återkapade %1$s"
 },
 "nplurals=2; plural=(n != 1);");
