@@ -120,6 +120,8 @@ OC.L10N.register(
     "Advanced settings" : "Avanserte innstillinger",
     "Delete" : "Slett",
     "Allow users to mount external storage" : "Tillat at brukere kobler opp eksterne lagre",
-    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring"
+    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring",
+    "SMB / CIFS" : "SMB / CIFS",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Noen av de konfigurerte eksterne oppkoblingspunktene er ikke tilkoblet. Klikk på de røde raden(e) for mer informasjon."
 },
 "nplurals=2; plural=(n != 1);");
