@@ -10,6 +10,7 @@ OC.L10N.register(
     "Shared with you" : "Mit Ihnen geteilt",
     "Shared with others" : "Von Ihnen geteilt",
     "Shared by link" : "Geteilt über einen Link",
+    "Federated sharing" : "Federated-Sharing",
     "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
     "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
     "Nothing shared yet" : "Noch nichts geteilt",
@@ -38,10 +39,22 @@ OC.L10N.register(
     "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
     "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
     "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
-    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
     "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
+    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
+    "Downloaded via public link" : "Über den öffentlichen Link heruntergeladen",
+    "Shared with %2$s" : "Geteilt mit %2$s",
+    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
+    "Shared with group %2$s" : "Geteilt mit der Gruppe %2$s",
+    "Shared with group %3$s by %2$s" : "Geteilt mit der Gruppe %3$s von %2$s",
+    "Shared via link by %2$s" : "Geteilt durch einen Link von %2$s",
+    "Shared via public link" : "Durch einen öffentlichen Link geteilt",
+    "Removed public link" : "entfernte öffentlichen Link",
+    "Public link expired" : "öffentlicher Link ist abgelaufen",
+    "Public link of %2$s expired" : "öffentlicher Link von %2$s ist abgelaufen",
+    "Shared by %2$s" : "Geteilt von %2$s",
     "Shares" : "Geteiltes",
     "Accept" : "Akzeptieren",
+    "Decline" : "Ablehnen",
     "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
     "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
     "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
@@ -67,7 +80,22 @@ OC.L10N.register(
     "Federated Cloud" : "Federated Cloud",
     "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
     "Share it:" : "Zum Teilen:",
+    "Add to your website" : "Zu Ihrer Website hinzufügen",
     "Share with me via ownCloud" : "Teilen Sie mit mir über ownCloud",
-    "HTML Code:" : "HTML-Code:"
+    "HTML Code:" : "HTML-Code:",
+    "Not allowed to create a federated share with the same user server" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
+    "Public link of %2$s expired" : "Öffentlicher Link von %2$s ist abgelaufen",
+    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
+    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
+    "Removed share for %2$s" : "Freigabe für %2$s entfernt",
+    "Removed share of group %2$s" : "Freigabe für Gruppe %2$s entfernt",
+    "Shared by %2$s" : "Geteilt von %2$s",
+    "Shared via link by %2$s" : "Geteilt durch einen Link von %2$s",
+    "Shared with group %3$s by %2$s" : "Geteilt mit der Gruppe %3$s von %2$s",
+    "The public link of %2$s for %1$s expired" : "Die Freigabe als Link von %2$s für %1$s ist abgelaufen",
+    "You removed the public link for %1$s" : "Sie haben die Freigabe als Link für %1$s entfernt",
+    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s entfernt",
+    "You removed the share of group %2$s for %1$s" : "Sie haben die Freigabe der Gruppe %2$s für %1$s entfernt",
+    "Your public link for %1$s expired" : "Ihre Freigabe als Link für %1$s ist abgelaufen"
 },
 "nplurals=2; plural=(n != 1);");
