@@ -1,8 +1,11 @@
 OC.L10N.register(
     "files_texteditor",
     {
+    "This file is too big to be opened. Please download the file instead." : "Die Datei ist zu groß zum öffnen. Bitte laden Sie stattdessen die Datei runter.",
     "Cannot read the file." : "Datei nicht lesbar.",
     "Invalid file path supplied." : "Ungültiger Dateipfad angegeben.",
+    "The file is locked." : "Die Datei ist gesperrt.",
+    "An internal server error occurred." : "Ein interner Serverfehler ist aufgetreten.",
     "Cannot save file as it has been modified since opening" : "Die Datei konnte nicht gespeichert werden, weil sie seit dem Öffnen verändert worden ist",
     "Insufficient permissions" : "Nicht ausreichende Berechtigungen",
     "File path not supplied" : "Dateipfad nicht angegeben",
@@ -11,6 +14,8 @@ OC.L10N.register(
     "saved!" : "gespeichert!",
     "failed!" : "fehlgeschlagen!",
     "Saved" : "Gespeichert",
-    "An error occurred!" : "Ein Fehler ist aufgetreten!"
+    "An error occurred!" : "Ein Fehler ist aufgetreten!",
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei file.txt"
 },
 "nplurals=2; plural=(n != 1);");
