@@ -3,6 +3,8 @@ $TRANSLATIONS = array(
 "This file is too big to be opened. Please download the file instead." => "Файл слишком большой для открытия. Пожалуйста скачайте его.",
 "Cannot read the file." => "Не удается прочитать файл.",
 "Invalid file path supplied." => "Указан некорректный путь.",
+"The file is locked." => "Файл заблокирован.",
+"An internal server error occurred." => "Произошла внутренняя ошибка сервера.",
 "Cannot save file as it has been modified since opening" => "Невозможно сохранить файл поскольку он был изменен после открытия ",
 "Insufficient permissions" => "Недостаточно прав доступа",
 "File path not supplied" => "Неизвестен путь файла",
@@ -12,6 +14,8 @@ $TRANSLATIONS = array(
 "failed!" => "ошибка!",
 "Saved" => "Сохранено",
 "There was a problem saving your changes. Click to resume editing." => "Произошла ошибка во время сохранения изменений. Нажмите для продолжения редактирования.",
-"An error occurred!" => "Произошла ошибка!"
+"An error occurred!" => "Произошла ошибка!",
+"Text file" => "Текстовый файл",
+"New text file.txt" => "Новый текстовый документ.txt"
 );
 $PLURAL_FORMS = "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);";
