@@ -4,6 +4,8 @@ OC.L10N.register(
     "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Weitere Informationen zur Aktualisierungen.",
     "Updater" : "Updater",
     "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "Aus Sicherheitsgründen nutzt der ownCloud Updater zusätzlichen Anmeldeinformationen. Um die Update-Seite aufzurufen, klicken Sie bitte auf den folgenden Button.",
-    "Open updater" : "Updater aufrufen"
+    "Open updater" : "Updater aufrufen",
+    "A new version is available: %s" : "Eine neue Version ist verfügbar: %s",
+    "Checked on %s" : "Überprüft auf %s"
 },
 "nplurals=2; plural=(n != 1);");
