@@ -2,6 +2,7 @@ OC.L10N.register(
     "updatenotification",
     {
     "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
-    "Updater" : "Aktualizátor"
+    "Updater" : "Aktualizátor",
+    "A new version is available: %s" : "Je dostupná nová verzia: %s"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
