@@ -6,15 +6,18 @@ OC.L10N.register(
     "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
     "Turned off maintenance mode" : "standsede vedligeholdelsestilstand",
     "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
+    "Updating database schema" : "Opdaterer database schema",
     "Updated database" : "Opdaterede database",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
     "Checked database schema update" : "Tjekket database schema opdatering",
+    "Checking updates of apps" : "Tjekker opdatering af apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
     "Checked database schema update for apps" : "Tjekkede databaseskemaets opdatering for apps",
     "Updated \"%s\" to %s" : "Opdaterede \"%s\" til %s",
     "Repair warning: " : "Reparationsadvarsel:",
     "Repair error: " : "Reparationsfejl:",
-    "Set log level to debug - current level: \"%s\"" : "Sæt log niveau til fejlfinding - nuværende niveau: \"%s\"",
-    "Reset log level to  \"%s\"" : "Nulstil log niveau til \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Følgende inkompatible apps er blevet deaktiveret: %s",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (inkombatible)",
     "Following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
     "Already up to date" : "Allerede opdateret",
     "File is too big" : "Filen er for stor",
@@ -22,10 +25,16 @@ OC.L10N.register(
     "No image or file provided" : "Ingen fil eller billede givet",
     "Unknown filetype" : "Ukendt filtype",
     "Invalid image" : "Ugyldigt billede",
+    "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
     "No temporary profile picture available, try again" : "Intet midlertidigt profilbillede tilgængeligt, prøv igen",
     "No crop data provided" : "Ingen beskæringsdata give",
     "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
     "Crop is not square" : "Beskæringen er ikke kvadratisk",
+    "Couldn't reset password because the token is invalid" : "Kunne ikke nulstille kodeordet, fordi symboludtrykket er ugyldigt",
+    "Couldn't reset password because the token is expired" : "Kunne ikke nulstille kodeord, da tokenet er udløbet",
+    "Couldn't send reset email. Please make sure your username is correct." : "Der opstod et problem under afsendelse af nulstillings-e-mailen. Kontroller venligst om dit brugernavnet er korrekt",
+    "%s password reset" : "%s adgangskode nulstillet",
+    "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
     "Sunday" : "Søndag",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
@@ -73,8 +82,8 @@ OC.L10N.register(
     "Dec." : "Dec.",
     "Settings" : "Indstillinger",
     "Saving..." : "Gemmer...",
+    "Dismiss" : "Afvis",
     "seconds ago" : "sekunder siden",
-    "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linket til at nulstille dit kodeord er blevet sendt til din e-post: hvis du ikke modtager den inden for en rimelig tid, så tjek dine spam/junk-mapper.<br> Hvis det ikke er der, så spørg din lokale administrator.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dine filer er krypterede. Hvis du ikke har aktiveret gendannelsesnøglen kan du ikke få dine data tilbage efter at du har ændret adgangskode.<br />Hvis du ikke er sikker på, hvad du skal gøre så kontakt din administrator før du fortsætter.<br />Vil du fortsætte?",
     "I know what I'm doing" : "Jeg ved, hvad jeg har gang i",
@@ -104,26 +113,21 @@ OC.L10N.register(
     "Strong password" : "Stærkt kodeord",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne ownCloud-server har ikke en fungerende forbindelse til internettet. Det betyder, at visse funktioner som montering af eksterne drev, oplysninger om opdatering eller installation af applikationer fra tredjepart ikke fungerer. Det vil sandsynligvis heller ikke være muligt at tilgå filer fra eksterne drev eller afsendelse af e-mail med notifikationer virker sandsynligvis heller ikke. Vi opfordrer til at etablere forbindelse til internettet for denne server, såfremt du ønsker samtlige funktioner.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. Filen .htaccess fungerer ikke. Vi anbefaler på det kraftigste, at du konfigurerer din webserver således at datamappen ikke længere er tilgængelig, eller at du flytter datamappen uden for webserverens dokumentrod.  ",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Der er ikke konfigureret et hukommelsesmellemlager. For at forbedre din ydelse, skal du konfigurere et mellemlager, hvis den er tilgængelig. Du finder mere information i din <a href=\"{docLink}\">dokumentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke læses af PHP, hvilket stærkt frarådes af sikkerhedsmæssige årsager. Der fås mere information i vores <a href=\"{docLink}\">dokumentation</a>.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Din version af PHP ({version}) bliver ikke længere <a href=\"{phpLink}\">understøttet af PHP</a>. Vi opfordrer dig til at opgradere din PHP-version, for at opnå fordelene i ydelse og sikkerhed gennem opdateringerne som fås fra PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Den omvendte konnfiguration af proxyen er ikke korrekt, eller også tilgår du ownCloud fra en proxy som der er tillid til. Hvis ikke tilgår ownCloud fra en proxy som der er tillid til, så er der er et sikkerhedsproblem, hvilket kan tillade at en angriber kan forfalske deres IP-adresse som synlig for ownCloud. Mere information fås i vores <a href=\"{docLink}\">dokumentation</a>.",
     "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. Filen .htaccess fungerer ikke. Vi anbefaler på det kraftigste, at du konfigurerer din webserver således at datamappen ikke længere er tilgængelig, eller at du flytter datamappen uden for webserverens dokumentrod.  ",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-hovedet \"{header}\" er ikke konfigureret til at være lig med \"{expected}\". Dette er en potentiel sikkerhedsrisiko, og vi anbefaler at du justerer denne indstilling.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP-hovedet \"Strict-Transport-Security\" er ikke konfigureret til mindst \"{seconds}\" sekunder. For udvidet sikkerhed anbefaler vi at aktivere HSTS, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du tilgår dette sted gennem HTTP. Vi anbefaler kraftigt at du konfigurerer din server, så der kræves brug af HTTPS i stedet for, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
     "Shared" : "Delt",
     "Shared with {recipients}" : "Delt med {recipients}",
     "Error" : "Fejl",
     "Error while sharing" : "Fejl under deling",
     "Error while unsharing" : "Fejl under annullering af deling",
-    "Error while changing permissions" : "Fejl under justering af rettigheder",
     "Error setting expiration date" : "Fejl under sætning af udløbsdato",
     "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
     "Set expiration date" : "Vælg udløbsdato",
     "Expiration" : "Udløb",
     "Expiration date" : "Udløbsdato",
+    "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
     "Sending ..." : "Sender ...",
     "Email sent" : "E-mail afsendt",
     "Resharing is not allowed" : "Videredeling ikke tilladt",
@@ -131,13 +135,11 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Beskyt med adgangskode",
     "Password" : "Adgangskode",
-    "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
     "Allow editing" : "Tillad redigering",
     "Email link to person" : "E-mail link til person",
     "Send" : "Send",
     "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
     "Shared with you by {owner}" : "Delt med dig af {owner}",
-    "Shared in {item} with {user}" : "Delt i {item} med {user}",
     "group" : "gruppe",
     "remote" : "ekstern",
     "notify by email" : "Giv besked med mail",
@@ -156,9 +158,10 @@ OC.L10N.register(
     "Share with users, groups or remote users …" : "Del med brugere, grupper eller eksterne brugere...",
     "Warning" : "Advarsel",
     "Error while sending notification" : "Fejl ved afsendelse af notifikation",
+    "Delete" : "Slet",
+    "Rename" : "Omdøb",
     "The object type is not specified." : "Objekttypen er ikke angivet.",
     "Enter new" : "Indtast nyt",
-    "Delete" : "Slet",
     "Add" : "Tilføj",
     "Edit tags" : "Redigér mærker",
     "Error loading dialog template: {error}" : "Fejl ved indlæsning dialog skabelon: {error}",
@@ -169,21 +172,13 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
     "Hello {name}" : "Hej {name}",
     "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
-    "{version} is available. Get more information on how to update." : "{version} er tilgængelig. Få mere information om hvordan du opdaterer.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Opgraderingen er i gang, forlader du denne side kan det afbryde processen.",
     "Updating {productName} to version {version}, this may take a while." : "Opdaterer {productName} til version {version}, det kan tage et stykke tid.",
+    "An error occurred." : "Der opstod en fejl.",
     "Please reload the page." : "Genindlæs venligst siden",
     "The update was unsuccessful. " : "Opdateringen blev ikke gennemført.",
     "The update was successful. There were warnings." : "Opdateringen blev gennemført. Der fremkom advarsler.",
     "The update was successful. Redirecting you to ownCloud now." : "Opdateringen blev udført korrekt. Du bliver nu viderestillet til ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Kunne ikke nulstille kodeordet, fordi symboludtrykket er ugyldigt",
-    "Couldn't reset password because the token is expired" : "Kunne ikke nulstille kodeord, da tokenet er udløbet",
-    "Couldn't send reset email. Please make sure your username is correct." : "Der opstod et problem under afsendelse af nulstillings-e-mailen. Kontroller venligst om dit brugernavnet er korrekt",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Der opstod et problem under afsendelse af nulstillings-e-mailen. Der ikke er nogen email adresse tilknyttet denne bruger konto. Kontakt venligst systemadministratoren",
-    "%s password reset" : "%s adgangskode nulstillet",
-    "Use the following link to reset your password: {link}" : "Anvend følgende link til at nulstille din adgangskode: {link}",
-    "New password" : "Ny adgangskode",
-    "New Password" : "Ny adgangskode",
-    "Reset password" : "Nulstil kodeord",
     "Searching other places" : "Søger på andre steder",
     "No search results in other folders" : "Søgning gav ingen resultater in andre mapper",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} søgeresultat fundet i andre mapper","{count} søgeresultater fundet i andre mapper"],
@@ -243,6 +238,7 @@ OC.L10N.register(
     "Finishing …" : "Færdigbehandler ...",
     "Need help?" : "Brug for hjælp?",
     "See the documentation" : "Se dokumentationen",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej med dig,<br><br>Dette er blot for at informere dig om, at %s har delt <strong>%s</strong> med dig.<br><a href=\"%s\">Se det her!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden. ",
     "Log out" : "Log ud",
     "Search" : "Søg",
@@ -252,15 +248,17 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
     "Log in" : "Log ind",
     "Wrong password. Reset it?" : "Forkert kodeord. Skal det nulstilles?",
-    "remember" : "husk",
+    "Stay logged in" : "Forbliv logget ind",
     "Alternative Logins" : "Alternative logins",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej med dig,<br><br>Dette er blot for at informere dig om, at %s har delt <strong>%s</strong> med dig.<br><a href=\"%s\">Se det her!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Anvend følgende link til at nulstille din adgangskode: {link}",
+    "New password" : "Ny adgangskode",
+    "New Password" : "Ny adgangskode",
+    "Reset password" : "Nulstil kodeord",
     "This ownCloud instance is currently in single user mode." : "Denne ownCloud instans er lige nu i enkeltbruger tilstand.",
     "This means only administrators can use the instance." : "Det betyder at det kun er administrator, som kan benytte ownCloud.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren, hvis denne meddelelse fortsætter eller optrådte uventet.",
     "Thank you for your patience." : "Tak for din tålmodighed.",
     "You are accessing the server from an untrusted domain." : "Du tilgår serveren fra et utroværdigt domæne",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontakt venligst din administrator. Hvis du er administrator, konfigurer \"trusted_domain\" indstillingen i config/config.php. Et eksempel kan ses i config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Afhænger af din konfiguration, da du som administrator eventuelt også er i stand til at gøre brug af knappen nedenfor til at tildele tillid til dette domæne.",
     "Add \"%s\" as trusted domain" : "Tilføj \"%s\" som et troværdigt domæne",
     "App update required" : "Opdatering af app påkræves",
@@ -272,6 +270,10 @@ OC.L10N.register(
     "Start update" : "Begynd opdatering",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
-    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen."
+    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen.",
+    "Error loading file picker template: {error}" : "Fejl ved indlæsning af filvælger skabelon: {error}",
+    "Error removing share" : "Fejl ved fjernelse af deling",
+    "invisible" : "usynlig",
+    "Password can not be changed. Please contact your administrator." : "Adgangskoden kunne ikke ændres. Kontakt venligst din administrator."
 },
 "nplurals=2; plural=(n != 1);");
