@@ -2,23 +2,45 @@ OC.L10N.register(
     "core",
     {
     "Couldn't send mail to following users: %s " : "Couldn't send mail to following users: %s ",
+    "Preparing update" : "Preparing update",
     "Turned on maintenance mode" : "Turned on maintenance mode",
     "Turned off maintenance mode" : "Turned off maintenance mode",
+    "Maintenance mode is kept active" : "Maintenance mode is kept active",
+    "Updating database schema" : "Updating database schema",
     "Updated database" : "Updated database",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema can be updated (this can take a long time depending on the database size)",
     "Checked database schema update" : "Checked database schema update",
+    "Checking updates of apps" : "Checking updates of apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
     "Checked database schema update for apps" : "Checked database schema update for apps",
     "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
     "Repair warning: " : "Repair warning: ",
     "Repair error: " : "Repair error: ",
-    "Following incompatible apps have been disabled: %s" : "Following incompatible apps have been disabled: %s",
+    "Set log level to debug" : "Set log level to debug",
+    "Reset log level" : "Reset log level",
+    "Starting code integrity check" : "Starting code integrity check",
+    "Finished code integrity check" : "Finished code integrity check",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (incompatible)",
+    "Following apps have been disabled: %s" : "Following apps have been disabled: %s",
+    "Already up to date" : "Already up to date",
+    "Please select a file." : "Please select a file.",
+    "File is too big" : "File is too big",
     "Invalid file provided" : "Invalid file provided",
     "No image or file provided" : "No image or file provided",
     "Unknown filetype" : "Unknown filetype",
     "Invalid image" : "Invalid image",
+    "An error occurred. Please contact your admin." : "An error occurred. Please contact your admin.",
     "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
     "No crop data provided" : "No crop data provided",
     "No valid crop data provided" : "No valid crop data provided",
     "Crop is not square" : "Crop is not square",
+    "Couldn't reset password because the token is invalid" : "Couldn't reset password because the token is invalid",
+    "Couldn't reset password because the token is expired" : "Couldn't reset password because the token is expired",
+    "Couldn't send reset email. Please make sure your username is correct." : "Couldn't send reset email. Please make sure your username is correct.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Could not send reset email because there is no email address for this username. Please contact your administrator.",
+    "%s password reset" : "%s password reset",
+    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "Sunday" : "Sunday",
     "Monday" : "Monday",
     "Tuesday" : "Tuesday",
@@ -33,6 +55,13 @@ OC.L10N.register(
     "Thu." : "Thu.",
     "Fri." : "Fri.",
     "Sat." : "Sat.",
+    "Su" : "Su",
+    "Mo" : "Mo",
+    "Tu" : "Tu",
+    "We" : "We",
+    "Th" : "Th",
+    "Fr" : "Fr",
+    "Sa" : "Sa",
     "January" : "January",
     "February" : "February",
     "March" : "March",
@@ -49,7 +78,7 @@ OC.L10N.register(
     "Feb." : "Feb.",
     "Mar." : "Mar.",
     "Apr." : "Apr.",
-    "May." : "May.",
+    "May." : "May",
     "Jun." : "Jun.",
     "Jul." : "Jul.",
     "Aug." : "Aug.",
@@ -57,10 +86,11 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>",
     "Settings" : "Settings",
     "Saving..." : "Saving...",
+    "Dismiss" : "Dismiss",
     "seconds ago" : "seconds ago",
-    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
     "I know what I'm doing" : "I know what I'm doing",
@@ -89,23 +119,30 @@ OC.L10N.register(
     "Good password" : "Good password",
     "Strong password" : "Strong password",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Your web server is not yet set up properly to allow file synchronisation because the WebDAV interface seems to be broken.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest enabling the Internet connection for this server.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
+    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>.",
     "Shared" : "Shared",
     "Shared with {recipients}" : "Shared with {recipients}",
     "Error" : "Error",
     "Error while sharing" : "Error whilst sharing",
     "Error while unsharing" : "Error whilst unsharing",
-    "Error while changing permissions" : "Error whilst changing permissions",
     "Error setting expiration date" : "Error setting expiration date",
     "The public link will expire no later than {days} days after it is created" : "The public link will expire no later than {days} days after it is created",
     "Set expiration date" : "Set expiration date",
     "Expiration" : "Expiration",
     "Expiration date" : "Expiration date",
+    "Choose a password for the public link" : "Choose a password for the public link",
     "Sending ..." : "Sending ...",
     "Email sent" : "Email sent",
     "Resharing is not allowed" : "Resharing is not allowed",
@@ -113,13 +150,11 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Password protect",
     "Password" : "Password",
-    "Choose a password for the public link" : "Choose a password for the public link",
     "Allow editing" : "Allow editing",
     "Email link to person" : "Email link to person",
     "Send" : "Send",
     "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
     "Shared with you by {owner}" : "Shared with you by {owner}",
-    "Shared in {item} with {user}" : "Shared in {item} with {user}",
     "group" : "group",
     "remote" : "remote",
     "notify by email" : "notify by email",
@@ -130,15 +165,29 @@ OC.L10N.register(
     "change" : "change",
     "delete" : "delete",
     "access control" : "access control",
+    "Could not unshare" : "Could not unshare",
+    "Share details could not be loaded for this item." : "Share details could not be loaded for this item.",
+    "No users or groups found for {search}" : "No users or groups found for {search}",
     "An error occured. Please try again" : "An error occured. Please try again",
+    "{sharee} (group)" : "{sharee} (group)",
+    "{sharee} (at {server})" : "{sharee} (at {server})",
+    "{sharee} (remote)" : "{sharee} (remote)",
     "Share" : "Share",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Share with people on other ownClouds using the syntax username@example.com/owncloud",
     "Share with users or groups …" : "Share with users or groups …",
     "Share with users, groups or remote users …" : "Share with users, groups or remote users …",
+    "Error removing share" : "Error removing share",
     "Warning" : "Warning",
+    "Error while sending notification" : "Error whilst sending notification",
+    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
+    "not assignable" : "not assignable",
+    "invisible" : "invisible",
+    "({scope})" : "({scope})",
+    "Delete" : "Delete",
+    "Rename" : "Rename",
+    "Collaborative tags" : "Collaborative tags",
     "The object type is not specified." : "The object type is not specified.",
     "Enter new" : "Enter new",
-    "Delete" : "Delete",
     "Add" : "Add",
     "Edit tags" : "Edit tags",
     "Error loading dialog template: {error}" : "Error loading dialog template: {error}",
@@ -149,20 +198,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
     "Hello {name}" : "Hello {name}",
     "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
-    "{version} is available. Get more information on how to update." : "{version} is available. Get more information on how to update.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "The upgrade is in progress, leaving this page might interrupt the process in some environments.",
     "Updating {productName} to version {version}, this may take a while." : "Updating {productName} to version {version}, this may take a while.",
+    "An error occurred." : "An error occurred.",
     "Please reload the page." : "Please reload the page.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
     "The update was unsuccessful. " : "The update was unsuccessful. ",
+    "The update was successful. There were warnings." : "The update was successful. There were warnings.",
     "The update was successful. Redirecting you to ownCloud now." : "The update was successful. Redirecting you to ownCloud now.",
-    "Couldn't reset password because the token is invalid" : "Couldn't reset password because the token is invalid",
-    "Couldn't send reset email. Please make sure your username is correct." : "Couldn't send reset email. Please make sure your username is correct.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Couldn't send reset email because there is no email address for this username. Please contact your administrator.",
-    "%s password reset" : "%s password reset",
-    "Use the following link to reset your password: {link}" : "Use the following link to reset your password: {link}",
-    "New password" : "New password",
-    "New Password" : "New Password",
-    "Reset password" : "Reset password",
     "Searching other places" : "Searching other places",
+    "No search results in other folders" : "No search results in other folders",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} search result in another folder","{count} search results in other folders"],
     "Personal" : "Personal",
     "Users" : "Users",
     "Apps" : "Apps",
@@ -219,6 +265,7 @@ OC.L10N.register(
     "Finishing …" : "Finishing …",
     "Need help?" : "Need help?",
     "See the documentation" : "See the documentation",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
     "Log out" : "Log out",
     "Search" : "Search",
@@ -227,22 +274,33 @@ OC.L10N.register(
     "An internal error occured." : "An internal error occured.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Log in" : "Log in",
-    "remember" : "remember",
+    "Wrong password. Reset it?" : "Wrong password. Reset it?",
+    "Wrong password." : "Wrong password.",
+    "Stay logged in" : "Stay logged in",
     "Alternative Logins" : "Alternative Logins",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Use the following link to reset your password: {link}",
+    "New password" : "New password",
+    "New Password" : "New Password",
+    "Reset password" : "Reset password",
     "This ownCloud instance is currently in single user mode." : "This ownCloud instance is currently in single user mode.",
     "This means only administrators can use the instance." : "This means only administrators can use the instance.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
     "Thank you for your patience." : "Thank you for your patience.",
     "You are accessing the server from an untrusted domain." : "You are accessing the server from an untrusted domain.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain.",
     "Add \"%s\" as trusted domain" : "Add \"%s\" as a trusted domain",
+    "App update required" : "App update required",
+    "%s will be updated to version %s" : "%s will be updated to version %s",
+    "These apps will be updated:" : "These apps will be updated:",
+    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
     "The theme %s has been disabled." : "The theme %s has been disabled.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
     "Start update" : "Start update",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
-    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again."
+    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again.",
+    "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
+    "Password can not be changed. Please contact your administrator." : "Password can not be changed. Please contact your administrator."
 },
 "nplurals=2; plural=(n != 1);");
