@@ -44,7 +44,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Приложението няма да бъде инсталирано, защото използва неразрешен код.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Приложението няма да бъде инсталирано, защото не е съвместимо с текущата версия на ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Приложението няма да бъде инсталирано, защото съдържа <shipped>true</shipped>, който таг не е разрешен за не ship-нати приложения.",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Приложението няма да бъде инсталирано, защото версията в info.xml/version не съвпада с версията публикувана в магазина за приложения.",
     "Application is not enabled" : "Приложението не е включено",
     "Authentication error" : "Проблем с идентификацията",
     "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
@@ -69,7 +68,6 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Неуспешно споделяне на %s  , защото сървъра не позволява споделяне от тип $i.",
     "Sharing %s failed, because the file does not exist" : "Неуспешно споделяне на %s, защото файлът не съществува.",
     "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
-    "Sharing %s failed, because the user %s is the item owner" : "Споделяне на %s е неуспешно, защото потребител %s е оригиналния собственик.",
     "Sharing %s failed, because the user %s does not exist" : "Неуспешно споделяне на %s, защото потребител %s не съществува.",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Неуспешно споделяне на %s, защото %s не е член никоя от групите, в които %s членува.",
     "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото това съдържание е вече споделено с %s.",
@@ -86,14 +84,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
     "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
     "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
-    "Sharing %s failed, because the user %s is the original sharer" : "Споделяне на %s е неуспешно, защото потребител %s е оригиналния собственик.",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Неуспешно споделяне на %s, защото промените надвишават правата на достъп дадени на %s.",
     "Sharing %s failed, because resharing is not allowed" : "Неуспешно споделяне на %s, защото повторно споделяне не е разрешено.",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Неуспешно споделяне на %s, защото не е открит първоизточникът на %s, за да бъде споделяне по сървъра.",
     "Sharing %s failed, because the file could not be found in the file cache" : "Неуспешно споделяне на %s, защото файлът не може да бъде намерен в кеша.",
     "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
     "Apps" : "Приложения",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Само следните символи са разрешени в потребителското име: \"a-z\", \"A-Z\", \"0-9\", и \"_.@-\".",
     "A valid username must be provided" : "Валидно потребителско име трябва да бъде зададено.",
     "A valid password must be provided" : "Валидна парола трябва да бъде зададена.",
     "The username is already being used" : "Това потребителско име е вече заето.",
@@ -113,12 +109,11 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
     "PostgreSQL >= 9 required" : "Изисква се PostgreSQL >= 9",
     "Please upgrade your database version" : "Моля, обнови базата данни.",
-    "Error occurred while checking PostgreSQL version" : "Настъпи грешка при проверката на версията на PostgreSQL.",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Моля, увери се, че PostgreSQL >= 9 или провери докладите за повече информация относно грешката.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, промени правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
     "Data directory (%s) is readable by other users" : "Data папката (%s) може да бъде разгледана от други потребители",
     "Data directory (%s) is invalid" : "Data папката (%s) e невалидна",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Моля, увери се, че data папката съдържа файл \".ocdata\" в себе си.",
-    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\".",
+    "Storage not available" : "Липсва дисковото устройство."
 },
 "nplurals=2; plural=(n != 1);");
