@@ -59,7 +59,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Aplikácia nemôže byť nainštalovaná pre nepovolený kód v aplikácii",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikácia nemôže byť nainštalovaná pre nekompatibilitu z touto verziou ownCloudu",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikácia nemôže byť nainštalovaná pretože obsahuje značku<shipped>true</shipped>, ktorá nie je povolená pre nedodávané aplikácie",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Aplikácia nemôže byť nainštalovaná pretože verzia v info.xml/version nezodpovedá verzii špecifikovanej v obchode s aplikáciami",
     "Application is not enabled" : "Aplikácia nie je zapnutá",
     "Authentication error" : "Chyba autentifikácie",
     "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
@@ -87,7 +86,6 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Zdieľanie %s zlyhalo, pretože backend nepodporuje typ zdieľania %i",
     "Sharing %s failed, because the file does not exist" : "Zdieľanie %s zlyhalo, pretože súbor neexistuje",
     "You are not allowed to share %s" : "Nemôžete zdieľať %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Zdieľanie %s zlyhalo, pretože používateľ %s je vlastníkom položky",
     "Sharing %s failed, because the user %s does not exist" : "Zdieľanie %s zlyhalo, pretože používateľ %s neexistuje",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Zdieľanie %s zlyhalo, pretože používateľ %s nie je členom žiadnej skupiny spoločnej s používateľom %s",
     "Sharing %s failed, because this item is already shared with %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je zdieľaná s %s",
@@ -106,14 +104,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend zdieľania %s musí implementovať rozhranie OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend zdieľania %s nebol nájdený",
     "Sharing backend for %s not found" : "Backend zdieľania pre %s nebol nájdený",
-    "Sharing %s failed, because the user %s is the original sharer" : "Zdieľanie %s zlyhalo, pretože používateľ %s je pôvodcom zdieľania",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Zdieľanie %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
     "Sharing %s failed, because resharing is not allowed" : "Zdieľanie %s zlyhalo, pretože zdieľanie ďalším nie je povolené",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Zdieľanie %s zlyhalo, backend zdieľania nenašiel zdrojový %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Zdieľanie %s zlyhalo, pretože súbor sa nenašiel vo vyrovnávacej pamäti súborov",
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
     "Apps" : "Aplikácie",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "V mene používateľa sú povolené len nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "The username is already being used" : "Meno používateľa je už použité",
@@ -140,14 +136,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Prosím, požiadajte administrátora vášho servera o reštartovanie webového servera.",
     "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
     "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
-    "Error occurred while checking PostgreSQL version" : "Nastala chyba pri overovaní verzie PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Prosím, uistite sa, že máte PostgreSQL >= 9 alebo sa pozrite do protokolu, kde nájdete podrobnejšie informácie o chybe",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
     "Data directory (%s) is readable by other users" : "Priečinok dát (%s) je prístupný na čítanie ostatným používateľom",
     "Data directory (%s) must be an absolute path" : "Priečinok dát (%s) musí byť zadaný ako absolútna cesta",
     "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
     "Data directory (%s) is invalid" : "Priečinok dát (%s) je neplatný",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Prosím, skontrolujte, či priečinok dát obsahuje súbor \".ocdata\".",
-    "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“."
+    "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“.",
+    "Storage not available" : "Úložisko nie je dostupné"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
