@@ -7,12 +7,10 @@ OC.L10N.register(
     "Cron" : "Cron",
     "Log" : "Jurnal",
     "Updates" : "Yenilənmələr",
-    "Authentication error" : "Təyinat metodikası",
-    "Your full name has been changed." : "Sizin tam adınız dəyişdirildi.",
-    "Unable to change full name" : "Tam adı dəyişmək olmur",
     "Couldn't remove app." : "Proqram təminatını silmək mümkün olmadı.",
     "Language changed" : "Dil dəyişdirildi",
     "Invalid request" : "Səhv müraciət",
+    "Authentication error" : "Təyinat metodikası",
     "Admins can't remove themself from the admin group" : "İnzibatçılar özlərini inzibatçı qrupundan silə bilməz",
     "Unable to add user to group %s" : "İstifadəçini %s qrupuna əlavə etmək mümkün olmadı",
     "Unable to remove user from group %s" : "İstifadəçini %s qrupundan silmək mümkün olmadı",
@@ -44,10 +42,13 @@ OC.L10N.register(
     "Invalid user" : "İstifadəçi adı yalnışdır",
     "Unable to change mail address" : "Mail ünvanını dəyişmək olmur",
     "Email saved" : "Məktub yadda saxlanıldı",
+    "Your full name has been changed." : "Sizin tam adınız dəyişdirildi.",
+    "Unable to change full name" : "Tam adı dəyişmək olmur",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" adını inamlı domainlər siyahısına əlavə etməyinizdən əminsinizmi?",
     "Add trusted domain" : "İnamlı domainlərə əlavə et",
     "Sending..." : "Göndərilir...",
     "All" : "Hamısı",
+    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
     "Update to %s" : "Yenilə bunadək %s",
     "Please wait...." : "Xahiş olunur gözləyəsiniz.",
     "Error while disabling app" : "Proqram təminatını dayandırdıqda səhv baş verdi",
@@ -60,17 +61,16 @@ OC.L10N.register(
     "Uninstalling ...." : "Silinir...",
     "Error while uninstalling app" : "Proqram təminatını sildikdə səhv baş verdi",
     "Uninstall" : "Sil",
+    "Valid until {date}" : "Müddətədək keçərlidir {date}",
+    "Delete" : "Sil",
     "Select a profile picture" : "Profil üçün şəkli seç",
     "Very weak password" : "Çox asan şifrə",
     "Weak password" : "Asan şifrə",
     "So-so password" : "Elə-belə şifrə",
     "Good password" : "Yaxşı şifrə",
     "Strong password" : "Çətin şifrə",
-    "Valid until {date}" : "Müddətədək keçərlidir {date}",
-    "Delete" : "Sil",
     "Groups" : "Qruplar",
     "Unable to delete {objName}" : "{objName} silmək olmur",
-    "Error creating group" : "Qrup yaranmasında səhv baş verdi",
     "A valid group name must be provided" : "Düzgün qrup adı təyin edilməlidir",
     "deleted {groupName}" : "{groupName} silindi",
     "undo" : "geriyə",
@@ -80,13 +80,11 @@ OC.L10N.register(
     "add group" : "qrupu əlavə et",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Şifrənin dəyişdirilməsi data itkisinə gətirəcək ona görə ki, datanın bərpası bu istifadəçi üçün movcud deyil.",
     "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
-    "Error creating user" : "İstifadəçi yaratdıqda səhv baş verdi",
     "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
     "A valid email must be provided" : "Düzgün email təqdim edilməlidir",
     "__language_name__" : "__AZ_Azerbaijan__",
-    "Sync clients" : "Müştəriləri sinxronizasiya et",
     "Personal info" : "Şəxsi məlumat",
-    "SSL root certificates" : "SSL root sertifikatları",
+    "Sync clients" : "Müştəriləri sinxronizasiya et",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Hər şey(ən pis hadisələr, səhvlər, xəbərdarlıqlar, məlmat, araşdırma səhvləri)",
     "Info, warnings, errors and fatal issues" : "Məlmat, xəbərdarlıqlar, səhvlər və ən pis hadisələr",
     "Warnings, errors and fatal issues" : "Xəbərdarlıqlar, səhvlər və ən pis hadisələr",
@@ -144,7 +142,6 @@ OC.L10N.register(
     "Store credentials" : "Səlahiyyətləri saxla",
     "Test email settings" : "Email qurmalarını test et",
     "Send email" : "Email yolla",
-    "Log level" : "Jurnal səviyyəsi",
     "Download logfile" : "Jurnal faylını endir",
     "More" : "Yenə",
     "Less" : "Az",
@@ -155,52 +152,44 @@ OC.L10N.register(
     "Advanced monitoring" : "İrəliləmiş monitoring",
     "Version" : "Versiya",
     "Developer documentation" : "Yaradıcı sənədləşməsi",
-    "by" : "onunla",
-    "licensed" : "Lisenziyalaşdırılıb",
     "Documentation:" : "Sənədləşmə:",
     "Show description …" : "Açıqlanmanı göstər ...",
     "Hide description …" : "Açıqlamanı gizlət ...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
     "Enable only for specific groups" : "Yalnız spesifik qruplara izin ver",
     "Uninstall App" : "Proqram təminatını sil",
-    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
+    "Common Name" : "Ümumi ad",
+    "Valid until" : "Vaxtadək keçərlidir",
+    "Issued By" : "Tərəfindən yaradılıb",
+    "Valid until %s" : "Keçərlidir vaxtadək %s",
+    "Import root certificate" : "root sertifikatı import et",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ey ora,<br><br>ancaq deyirik ki, sizin artiq %s hesabınız var.<br><br>Sizin istifadəçi adınız: %s<br>Yetkilidir: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Şərəfə!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ey ora,\n\nancaq deyirik ki, sizin artiq %s hesabınız var.\n\nizin istifadəçi adınız: %s\nYetkilidir: %s\n\n",
     "Forum" : "Forum",
+    "Profile picture" : "Profil şəkli",
+    "Upload new" : "Yenisini yüklə",
+    "Remove image" : "Şəkili sil",
+    "Cancel" : "Dayandır",
+    "Full name" : "Tam ad",
+    "No display name set" : "Ekranda adı dəsti yoxdur",
+    "Email" : "Email",
+    "Your email address" : "Sizin email ünvanı",
+    "No email address set" : "Email ünvanı dəsti yoxdur",
+    "You are member of the following groups:" : "Siz göstərilən qrupların üzvüsünüz:",
+    "Password" : "Şifrə",
+    "Unable to change your password" : "Sizin şifrəni dəyişmək mümkün olmadı",
+    "Current password" : "Hazırkı şifrə",
+    "New password" : "Yeni şifrə",
+    "Change password" : "Şifrəni dəyiş",
+    "Language" : "Dil",
+    "Help translate" : "Tərcüməyə kömək",
     "Get the apps to sync your files" : "Fayllarınızın sinxronizasiyası üçün proqramları götürün",
     "Desktop client" : "Desktop client",
     "Android app" : "Android proqramı",
     "iOS app" : "iOS proqramı",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Əgər siz proektə dəstək vermək istəyirsinizsə\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">Təkmilləşdirməyə üzv</a>\n\t\tyada\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">söz yaymaq</a>!",
     "Show First Run Wizard again" : "İlk işəsalma sehirbazını yenidən göstər",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Siz istifadə etdiniz <strong>%s</strong> mövcud olan <strong>%s</strong>",
-    "Password" : "Şifrə",
-    "Unable to change your password" : "Sizin şifrəni dəyişmək mümkün olmadı",
-    "Current password" : "Hazırkı şifrə",
-    "New password" : "Yeni şifrə",
-    "Change password" : "Şifrəni dəyiş",
-    "Full name" : "Tam ad",
-    "No display name set" : "Ekranda adı dəsti yoxdur",
-    "Email" : "Email",
-    "Your email address" : "Sizin email ünvanı",
-    "Fill in an email address to enable password recovery and receive notifications" : "Email ünvanını doldurun ki, sifrənizin bərpa edilməsini işə salasınız və məktubla xəbərdarlıqları qəbul edəsiniz.",
-    "No email address set" : "Email ünvanı dəsti yoxdur",
-    "You are member of the following groups:" : "Siz göstərilən qrupların üzvüsünüz:",
-    "Profile picture" : "Profil şəkli",
-    "Upload new" : "Yenisini yüklə",
-    "Select new from Files" : "Fayllardan yenisini seç",
-    "Remove image" : "Şəkili sil",
-    "Your avatar is provided by your original account." : "Sizin avatar sizin original hesab tərəfindən təqdim edilib.",
-    "Cancel" : "Dayandır",
-    "Choose as profile image" : "Profayl şəklini seçin",
-    "Language" : "Dil",
-    "Help translate" : "Tərcüməyə kömək",
-    "Common Name" : "Ümumi ad",
-    "Valid until" : "Vaxtadək keçərlidir",
-    "Issued By" : "Tərəfindən yaradılıb",
-    "Valid until %s" : "Keçərlidir vaxtadək %s",
-    "Import root certificate" : "root sertifikatı import et",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Tərəfindən yaradılıb{communityopen}ownCloud cəmiyyəti{linkclose},   {githubopen}mənbə kodları{linkclose} altında lisenziya edilib {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Depo ünvanını göstər",
     "Show last log in" : "Son girişi göstər",
