@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Logg",
     "Tips & tricks" : "Tips og triks",
     "Updates" : "Oppdateringer",
-    "Authentication error" : "Autentiseringsfeil",
-    "Your full name has been changed." : "Ditt fulle navn er blitt endret.",
-    "Unable to change full name" : "Klarte ikke å endre fullt navn",
     "Couldn't remove app." : "Klarte ikke å fjerne app.",
     "Language changed" : "Språk endret",
     "Invalid request" : "Ugyldig forespørsel",
+    "Authentication error" : "Autentiseringsfeil",
     "Admins can't remove themself from the admin group" : "Admin kan ikke flytte seg selv fra admingruppen",
     "Unable to add user to group %s" : "Kan ikke legge bruker til gruppen %s",
     "Unable to remove user from group %s" : "Kan ikke slette bruker fra gruppen %s",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Ugyldig bruker",
     "Unable to change mail address" : "Kan ikke endre epost-adresse",
     "Email saved" : "Epost lagret",
+    "Your full name has been changed." : "Ditt fulle navn er blitt endret.",
+    "Unable to change full name" : "Klarte ikke å endre fullt navn",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ønsker du virkelig å legge til \"{domain}\" som tiltrodd domene?",
     "Add trusted domain" : "Legg til et tiltrodd domene",
     "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til migreringen er ferdig.",
@@ -62,10 +62,12 @@ OC.L10N.register(
     "Approved" : "Godkjent",
     "Experimental" : "Eksperimentell",
     "All" : "Alle",
+    "No apps found for your version" : "Ingen apper funnet for din versjon",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offisielle apper utvikles av og innenfor ownCloud-fellesskapet. De tilbyr funksjonalitet som er sentral for ownCloud og er forberedt for produksjonsbruk.",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkjente apper er utviklet av pålitelige utviklere og har gjennomgått en rask sikkerhetssjekk. De vedlikeholdes aktivt i et åpent kode-depot og utviklerne anser dem for å være stabile for tilfeldig til normal bruk.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkjente apper er utviklet av pålitelige utviklere og har gjennomgått en rask sikkerhetssjekk. De vedlikeholdes aktivt i et åpent kode-depot og utviklerne anser dem for å være stabile for tidvis eller normal bruk.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Denne appen er ikke sjekket for sikkerhetsproblemer og er ny eller ansett for å være ustabil. Installer på egen risiko.",
     "Update to %s" : "Oppdater til %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Du har %n app-oppdatering som venter","Du har %n app-oppdateringer som venter"],
     "Please wait...." : "Vennligst vent...",
     "Error while disabling app" : "Deaktivering av app feilet",
     "Disable" : "Deaktiver ",
@@ -77,6 +79,12 @@ OC.L10N.register(
     "Uninstalling ...." : "Avinstallerer ....",
     "Error while uninstalling app" : "Feil ved avinstallering av app",
     "Uninstall" : "Avinstaller",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli omdirigert til oppdateringssiden om 5 sekunder.",
+    "App update" : "Oppdatering av applikasjon",
+    "No apps found for \"{query}\"" : "Ingen apper funnet for \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Vennligst last opp et ASCII-kodet PEM-sertifikat.",
+    "Valid until {date}" : "Gyldig til {date}",
+    "Delete" : "Slett",
     "An error occurred: {message}" : "Det oppstod en feil: {message}",
     "Select a profile picture" : "Velg et profilbilde",
     "Very weak password" : "Veldig svakt passord",
@@ -84,12 +92,9 @@ OC.L10N.register(
     "So-so password" : "So-so-passord",
     "Good password" : "Bra passord",
     "Strong password" : "Sterkt passord",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Vennligst last opp et ASCII-kodet PEM-sertifikat.",
-    "Valid until {date}" : "Gyldig til {date}",
-    "Delete" : "Slett",
     "Groups" : "Grupper",
     "Unable to delete {objName}" : "Kan ikke slette {objName}",
-    "Error creating group" : "Feil ved oppretting av gruppe",
+    "Error creating group: {message}" : "Feil ved oppretting av gruppe: {message}",
     "A valid group name must be provided" : "Et gyldig gruppenavn må oppgis",
     "deleted {groupName}" : "slettet {groupName}",
     "undo" : "angre",
@@ -99,13 +104,12 @@ OC.L10N.register(
     "add group" : "legg til gruppe",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Forandring av passordet vil føre til tap av data, fordi datagjennoppretting er utilgjengelig for denne brukeren",
     "A valid username must be provided" : "Oppgi et gyldig brukernavn",
-    "Error creating user" : "Feil ved oppretting av bruker",
+    "Error creating user: {message}" : "Feil ved oppretting av bruker: {message}",
     "A valid password must be provided" : "Oppgi et gyldig passord",
     "A valid email must be provided" : "En gyldig e-postadresse må oppgis",
     "__language_name__" : "__language_name__",
-    "Sync clients" : "Synkroniseringsklienter",
     "Personal info" : "Personlig informasjon",
-    "SSL root certificates" : "SSL rotsertifikater",
+    "Sync clients" : "Synkroniseringsklienter",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Alt (fatale problemer, feil, advarsler, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, advarsler, feil og fatale problemer",
     "Warnings, errors and fatal issues" : "Advarsler, feil og fatale problemer",
@@ -123,7 +127,7 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Serveren din kjører på Microsoft Windows. Vi anbefaler strekt Linux for en optimal brukeropplevelse.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s lavere enn versjon %2$s er installert. Vi anbefaler å oppgradere til en nyere %1$s-versjon for å få bedre stabilitet og ytelse.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s lavere enn versjon %2$s er installert. Vi anbefaler å oppgradere til en nyere %1$s-versjon for å få bedre stabilitet og ytelse.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modulen 'fileinfo' mangler. Vi anbefaler at du aktiverer denne modulen for å kunne detektere mime-typen korrekt.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing er deaktivert. Dette kan føre til problemer med kappløpssituasjoner. Aktiver 'filelocking.enabled' i config.php for å unngå disse problemene. Se <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
     "System locale can not be set to a one which supports UTF-8." : "Kan ikke sette systemets nasjonale innstillinger til en som støtter UTF-8.",
@@ -131,7 +135,6 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vi anbefaler sterkt å installere de påkrevde pakkene på systemet ditt for å støtte en av følgende nasjonale innstillinger: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Hvis installasjonen din ikke er installert i roten av domenet og bruker systemets cron, kan det bli problemer med URL-genereringen. For å unngå disse problemene, sett \"overwrite.cli.url\" i filen config.php til web-roten for installasjonen din (Foreslått: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Det var ikke mulig å kjøre cron-jobben vi CLI. Følgende tekniske feil oppstod:",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing bruker databasen som låsemekanisme. For best ytelse anbefales det å konfigurerer en memcache for låsing. Se <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Vennligst dobbeltsjekk <a target=\"_blank\" href=\"%s\">Installasjonsveiledningene ↗</a> og se etter feil og advarsler i <a href=\"#log-section\">loggen</a>.",
     "All checks passed." : "Alle sjekker bestått.",
     "Open documentation" : "Åpne dokumentasjonen",
@@ -149,6 +152,7 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Tillat at brukere sender varsler om delte filer på e-post til andre brukere",
     "Exclude groups from sharing" : "Utelukk grupper fra deling",
     "These groups will still be able to receive shares, but not to initiate them." : "Disse gruppene vil fremdeles kunne motta delinger men ikke lage dem.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Tillat automatisk fullføring av brukernavn i delingsdialogen. Uten dette valget må hele brukernavnet oppgis.",
     "Last cron job execution: %s." : "Siste kjøring av cron-jobb: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Siste kjøring av cron-jobb: %s. Noe ser ut til å være galt.",
     "Cron was not executed yet!" : "Cron er ikke utført ennå!",
@@ -157,6 +161,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Bruk systemets cron-tjeneste til å kalle cron.php hvert 15. minutt.",
     "Enable server-side encryption" : "Aktiver serverkryptering",
     "Please read carefully before activating server-side encryption: " : "Vennligst les dette nøye før du aktiverer serverkrykptering:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er blitt aktivert, vil alle filer som lastes opp til serveren fra det tidspunktet av bli lagret kryptert på serveren. Det vil kun være mulig å deaktivere kryptering senere dersom den aktive krypteringsmodulen støtter det og alle forutsetninger (f.eks. å sette en gjenopprettingsnøkkel) er til stede.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Kryptering alene garanterer ikke sikkerheten i systemet. Se ownCloud-dokumentasjonen for mer informasjon om hvordan krypterings-appen virker og hvilke brukstilfeller som støttes.",
+    "Be aware that encryption always increases the file size." : "Vær oppmerksom på at kryptering alltid øker filstørrelsen.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er alltid bra å ta regelmessig sikkerhetskopi av dataene dine. Pass på å ta kopi av krypteringsnøklene sammen med dataene når kryptering er i bruk.",
     "This is the final warning: Do you really want to enable encryption?" : "Dette er siste advarsel: Vil du virkelig aktivere kryptering?",
     "Enable encryption" : "Aktiver kryptering",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul er lastet. Aktiver en krypteringsmodul i app-menyen.",
@@ -179,36 +187,44 @@ OC.L10N.register(
     "Store credentials" : "Lagre påloggingsdetaljer",
     "Test email settings" : "Test innstillinger for e-post",
     "Send email" : "Send e-post",
-    "Log level" : "Loggnivå",
     "Download logfile" : "Last ned loggfil",
     "More" : "Mer",
     "Less" : "Mindre",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Loggfilen er over 100 MB, nedlastingen kan ta en stund!",
+    "What to log" : "Hva som skal logges",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite brukes som database. For større installasjoner anbefaler vi å bytte til en annen database-server.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite er spesielt frarådet om man bruker desktopklienten til filsynkronisering",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: 'occ db:convert-type', eller les i <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a>.",
     "How to do backups" : "Hvordan ta sikkerhetskopier",
     "Advanced monitoring" : "Avansert overvåking",
-    "Performance tuning" : "Tilpassing av ytelse",
-    "Improving the config.php" : "Forbedring av config.php",
+    "Performance tuning" : "Forbedre ytelsen",
+    "Improving the config.php" : "Tilpasninger i config.php",
     "Theming" : "Temaer",
     "Hardening and security guidance" : "Herding og sikkerhetsveiledning",
     "Version" : "Versjon",
     "Developer documentation" : "Utviklerdokumentasjon",
     "Experimental applications ahead" : "Eksperimentelle applikasjoner forut",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Eksperimentelle apper er ikke sjekket for sikkerhetsproblemer, de er nye eller de anses som ustabile og under kontinuerlig utvikling. Å installere slike apper kan forårsake tap av data eller sikkerhetsbrudd.",
-    "by" : "av",
-    "licensed" : "lisensiert",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Eksperimentelle apper er ikke sjekket for sikkerhetsproblemer. De er nye eller de anses som ustabile og under stadig utvikling. Å installere slike apper kan forårsake tap av data eller brudd på sikkerheten.",
+    "by %s" : "av %s",
+    "%s-licensed" : "%s-lisensiert",
     "Documentation:" : "Dokumentasjon:",
     "User documentation" : "Brukerdokumentasjon",
     "Admin documentation" : "Admin-dokumentasjon",
     "Show description …" : "Vis beskrivelse …",
     "Hide description …" : "Skjul beskrivelse …",
+    "This app has an update available." : "En oppdatering er tilgjengelig for denne appen.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne appen har ingen minimumsversjon av ownCloud. Dette vil være en feil i ownCloud 11 og senere.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne appen har ingen maksimumsversjon av ownCloud. Dette vil være en feil i ownCloud 11 og senere.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Denne appen kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt:",
     "Enable only for specific groups" : "Aktiver kun for visse grupper",
     "Uninstall App" : "Avinstaller app",
     "Enable experimental apps" : "Aktiver eksperimentelle apper",
-    "No apps found for your version" : "Ingen apper funnet for din versjon",
+    "SSL Root Certificates" : "SSL rotsertifikater",
+    "Common Name" : "Vanlig navn",
+    "Valid until" : "Gyldig til",
+    "Issued By" : "Utstedt av",
+    "Valid until %s" : "Gyldig til %s",
+    "Import root certificate" : "Importer rotsertifikat",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hei,<br><br>vil bare informere om at du nå har en %s-konto.<br><br>Brukernavnet ditt: %s<br>Gå dit: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Ha det!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hei,\n\nVil bare informere om at du nå har en %s-konto.\n\nBrukernavnet ditt: %s\nGå dit: %s\n\n",
@@ -217,40 +233,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Problemsporing",
     "Commercial support" : "Forretningsstøtte",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Du bruker <strong>%s</strong> av <strong>%s</strong>",
+    "Profile picture" : "Profilbilde",
+    "Upload new" : "Last opp nytt",
+    "Select from Files" : "Velg fra Filer",
+    "Remove image" : "Fjern bilde",
+    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
+    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
+    "Cancel" : "Avbryt",
+    "Choose as profile picture" : "Velg som profilbilde",
+    "Full name" : "Fullt navn",
+    "No display name set" : "Visningsnavn ikke satt",
+    "Email" : "Epost",
+    "Your email address" : "Din e-postadresse",
+    "For password recovery and notifications" : "For passord-gjenoppretting og varsler",
+    "No email address set" : "E-postadresse ikke satt",
+    "You are member of the following groups:" : "Du er medlem av følgende grupper:",
+    "Password" : "Passord",
+    "Unable to change your password" : "Kunne ikke endre passordet ditt",
+    "Current password" : "Nåværende passord",
+    "New password" : "Nytt passord",
+    "Change password" : "Endre passord",
+    "Language" : "Språk",
+    "Help translate" : "Bidra til oversettelsen",
     "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
     "Desktop client" : "Skrivebordsklient",
     "Android app" : "Android-app",
     "iOS app" : "iOS-app",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Hvis du vil støtte prosjektet kan du\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">delta i utviklingen</a>\n\t\teller\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spre budskapet</a>!",
     "Show First Run Wizard again" : "Vis \"Førstegangs veiviser\" på nytt",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Du har brukt <strong>%s</strong> av de tilgjengelige <strong>%s</strong>",
-    "Password" : "Passord",
-    "Unable to change your password" : "Kunne ikke endre passordet ditt",
-    "Current password" : "Nåværende passord",
-    "New password" : "Nytt passord",
-    "Change password" : "Endre passord",
-    "Full name" : "Fullt navn",
-    "No display name set" : "Visningsnavn ikke satt",
-    "Email" : "Epost",
-    "Your email address" : "Din e-postadresse",
-    "Fill in an email address to enable password recovery and receive notifications" : "Legg inn en e-postadresse for å aktivere passordgjenfinning og motta varsler",
-    "No email address set" : "E-postadresse ikke satt",
-    "You are member of the following groups:" : "Du er medlem av følgende grupper:",
-    "Profile picture" : "Profilbilde",
-    "Upload new" : "Last opp nytt",
-    "Select new from Files" : "Velg nytt fra Filer",
-    "Remove image" : "Fjern bilde",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Enten png eller jpg. Helst kvadratisk, men du kan beskjære bildet. Filen kan ikke være større enn 20 MB.",
-    "Your avatar is provided by your original account." : "Avataren din kommer fra din opprinnelige konto.",
-    "Cancel" : "Avbryt",
-    "Choose as profile image" : "Velg som profilbilde",
-    "Language" : "Språk",
-    "Help translate" : "Bidra til oversettelsen",
-    "Common Name" : "Vanlig navn",
-    "Valid until" : "Gyldig til",
-    "Issued By" : "Utstedt av",
-    "Valid until %s" : "Gyldig til %s",
-    "Import root certificate" : "Importer rotsertifikat",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Utviklet av {communityopen}ownCloud-fellesskapet{linkclose}. {githubopen}Kildekoden{linkclose} er lisensiert under {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Vis lagringssted",
     "Show last log in" : "Vis site innlogging",
